Reference
=========

.. module:: puq
   :platform: Linux, MacOSX
   :synopsis: PRISM Uncertainty Quantification framework
.. moduleauthor:: Martin Hunt <mmh@purdue.edu>

.. toctree::
   :maxdepth: 3

   reference/calibrate.rst
   reference/hdf.rst   
   reference/hosts.rst   
   reference/parameters.rst   
   reference/pdf.rst
   reference/puqutil.rst   
   reference/smolyak.rst
   reference/sweep.rst   
   reference/testprogram.rst
   reference/psweep.rst
   